@@ -218,7 +218,7 @@ func stripCRDs(bigFile string, c *action.Configuration) (string, bool, error) {
 	manifests := releaseutil.SplitManifests(bigFile)
 	_, files, err := releaseutil.SortManifests(manifests, caps.APIVersions, releaseutil.InstallOrder)
 	if err != nil {
-		return "", false, fmt.Errorf("corrupted release record. You must manually delete the resources %w", err)
+		return "", false, fmt.Errorf("corrupted release record. %w", err)
 	}
 
 	var builder strings.Builder
